==> qtjambi-designer-debuginfo-macos-5.15.20.jar: sources/QtJambiDesigner/QDesignerWidgetDataBaseInterface_shell.h <==
#ifndef QDESIGNERWIDGETDATABASEINTERFACE_SHELL_H
#define QDESIGNERWIDGETDATABASEINTERFACE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtDesigner/abstractwidgetdatabase.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtDesigner/abstractformeditor.h>
#include <QtJambi/RegistryAPI>


class QDesignerWidgetDataBaseInterface_shell : public QDesignerWidgetDataBaseInterface, public QtJambiShellInterface
{
public:
    QDesignerWidgetDataBaseInterface_shell(QObject* parent0 = nullptr);
    ~QDesignerWidgetDataBaseInterface_shell() override;

    void append(QDesignerWidgetDataBaseItemInterface* item0) override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QDesignerFormEditorInterface* core() const override;
    int count() const override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    int indexOf(QDesignerWidgetDataBaseItemInterface* item0) const override;
    int indexOfClassName(const QString& className0, bool resolveName1) const override;
    int indexOfObject(QObject* object0, bool resolveName1) const override;
    void insert(int index0, QDesignerWidgetDataBaseItemInterface* item1) override;
    QDesignerWidgetDataBaseItemInterface* item(int index0) const override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QDesignerWidgetDataBaseInterface_access : public QDesignerWidgetDataBaseInterface
{
    void __qt_append_QDesignerWidgetDataBaseItemInterface_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID item0);
    jobject __qt_core_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_count_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_indexOf_QDesignerWidgetDataBaseItemInterface_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID item0) const;
    jint __qt_indexOfClassName_cref_QString_bool_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring className0, jboolean resolveName1) const;
    jint __qt_indexOfObject_QObject_ptr_bool_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID object0, jboolean resolveName1) const;
    void __qt_insert_int_QDesignerWidgetDataBaseItemInterface_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint index0, QtJambiNativeID item1);
    jobject __qt_item_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint index0) const;
    void setItems_cref_QList(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject items0);
    jobject items(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QDESIGNERWIDGETDATABASEINTERFACE_SHELL_H

==> qtjambi-designer-debuginfo-macos-6.5.3.jar: sources/QtJambiDesigner/QDesignerWidgetDataBaseInterface_shell.h <==
#ifndef QDESIGNERWIDGETDATABASEINTERFACE_SHELL_H
#define QDESIGNERWIDGETDATABASEINTERFACE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtDesigner/abstractwidgetdatabase.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtDesigner/abstractformeditor.h>
#include <QtJambi/RegistryAPI>


class QDesignerWidgetDataBaseInterface_shell : public QDesignerWidgetDataBaseInterface, public QtJambiShellInterface
{
public:
    QDesignerWidgetDataBaseInterface_shell(QObject* parent0 = nullptr);
    ~QDesignerWidgetDataBaseInterface_shell() override;

    void append(QDesignerWidgetDataBaseItemInterface* item0) override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QDesignerFormEditorInterface* core() const override;
    int count() const override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    int indexOf(QDesignerWidgetDataBaseItemInterface* item0) const override;
    int indexOfClassName(const QString& className0, bool resolveName1) const override;
    int indexOfObject(QObject* object0, bool resolveName1) const override;
    void insert(int index0, QDesignerWidgetDataBaseItemInterface* item1) override;
    QDesignerWidgetDataBaseItemInterface* item(int index0) const override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QDesignerWidgetDataBaseInterface_access : public QDesignerWidgetDataBaseInterface
{
    void __qt_append_QDesignerWidgetDataBaseItemInterface_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID item0);
    jobject __qt_core(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_count(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_indexOf_QDesignerWidgetDataBaseItemInterface_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID item0) const;
    jint __qt_indexOfClassName_cref_QString_bool_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring className0, jboolean resolveName1) const;
    jint __qt_indexOfObject_QObject_ptr_bool_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID object0, jboolean resolveName1) const;
    void __qt_insert_int_QDesignerWidgetDataBaseItemInterface_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint index0, QtJambiNativeID item1);
    jobject __qt_item_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint index0) const;
    void setItems_cref_QList(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject items0);
    jobject items(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QDESIGNERWIDGETDATABASEINTERFACE_SHELL_H
